﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using VR_Sample_Application.VRAPI;

namespace VR_Sample_Application
{
   class Program
        {                         
            static void Main(string[] args)
            {                
                /* 
                 * FOR DEVELOPERS WITH PARTNER ACCOUNTS:
                 * If you are testing Partner-specific features, you will need your certificates installed correctly.
                 * This page will help you set up your certificates: http://developers.verticalresponse.com/api/soap/developers-reference/partner-resources/c-net-certificate-configuration-guide/ 
                 * To make calls on *behalf of users*, use the impersonate_user argument on login. Do not use impersonate_user when creating users or companies.
                */

                /*
                 * FOR EVERYONE:
                 * This code will walk you through logging in, creating a list and an email campaign, attaching that list to that email campaign, and launching it. 
                 * There are several points at which you can update the content -- email addresses, email subject line, etc., but the only required edits to this code
                 * are providing your username and password below.
                */

                System.Console.WriteLine("Starting Program!");

                System.Console.WriteLine("Logging In...");
                loginArgs objLA = new loginArgs();
                objLA.username = "USERNAME"; // Your VerticalResponse username
                objLA.password = "PASSWORD"; //Your VerticalResponse password
                // objLA.impersonate_user = "subaccount@emailaddress.com"; // If accessing or acting as a subaccount, uncomment this and replace it with the applicable email address.
                objLA.session_duration_minutes = "120";
                DateTime date = DateTime.Now;

                // This is generated by creating a Service Reference that points to the VerticalResponse WSDL. 
                VRAPIPortTypeClient objVR = new VRAPIPortTypeClient();

                // Let's try to log in. The login call will return a session ID, which we will use in all subsequent calls.
                string sessionId = null;
                try
                {
                    sessionId = objVR.login(objLA);
                }
                catch (Exception e)
                {
                    System.Console.WriteLine(e.Message);
                }

                System.Console.WriteLine("Logged in! Session key:" + sessionId);
               
                createListArgs objCLA = new createListArgs();
                objCLA.name = "C# Test List: " + date;
                objCLA.session_id =  sessionId;
                
               // Let's create a test list.
               int listId = 0;
               try
                {
                    listId = objVR.createList(objCLA);
                }
                catch (Exception e)
                {
                    System.Console.WriteLine(e.Message);
                }

               System.Console.WriteLine("List " + date + " created. List ID: " + listId);

               /* 
                * Let's add a contact to that test list. Feel encouraged to replace the values with your contact info. 
                * Most of the time you will be adding list members using the method appendFileToList, since looping over addListMember can cause significant lag.
                * Check out the docs at http://developers.verticalresponse.com for a code snippet using appendFileToList.
               */ 
               
               ListMember objLM = new ListMember();
               objLM.list_id = listId;
               NVPair[] memberData = new NVPair[3];

               memberData[0] = new NVPair();
               memberData[0].name = "email_address";
               memberData[0].value = "youremail@exmample.com"; // Adding yourself to the list would handy for using the list for testing.

               memberData[1] = new NVPair();
               memberData[1].name = "first_name";
               memberData[1].value = "Example";

               memberData[2] = new NVPair();
               memberData[2].name = "last_name";
               memberData[2].value = "List Member";

               objLM.member_data = memberData;

               addListMemberArgs objAL = new addListMemberArgs();

               objAL.list_member = objLM;
               objAL.session_id = sessionId;

               try
               {
                   objVR.addListMember(objAL);
               }
               catch (Exception e)
               {
                   System.Console.WriteLine(e.Message);
               }

               // Now for creating a test message. You can replace any of the content with your own.
               Email objEmail = new Email();
                              
               objEmail.email_type = "canvas";
               objEmail.freeform_html = "<h1>This is an HTML email created by the VerticalResponse C# Sample Code!</h1><p>You can edit this however you please.</p>";
               objEmail.freeform_text = "This is a Text email created by the VerticalResponse C# Sample Code! You can edit this however you please.";
               objEmail.from_label = "VerticalResponse C# Sample Code";
               objEmail.name = "C# Test: " + date;
               objEmail.subject = "VerticalResponse C# Sample Code Test Email";
               objEmail.reply_to_email = objLA.username;
               objEmail.unsub_message = "If you would to be removed from our list";
               objEmail.unsub_link_text = "Click Here to Unsubscribe";
               objEmail.postal_addr_1 = "50 Beale Street, Floor 10";
               objEmail.postal_city = "San Francisco";
               objEmail.postal_state = "California";
               objEmail.postal_code = "94105";
               objEmail.postal_country = "USA";

               // You should set these to false only if your users will use the VerticalResponse website to create their emails. In that case, they will preview & test via our site.
               objEmail.previewed_html = true;
               objEmail.previewed_htmlSpecified = true;
               objEmail.previewed_text = true;
               objEmail.previewed_textSpecified = true;
               objEmail.tested = true;
               objEmail.testedSpecified = true;

               createEmailArgs objCE = new createEmailArgs();
               objCE.session_id = sessionId;
               objCE.email = objEmail;
               int campaignId = 0;

               try
               {
                   campaignId = objVR.createEmail(objCE);
                }
               catch (Exception e)
               {
                   System.Console.WriteLine(e.Message);
               }

               System.Console.WriteLine("Campaign " + objEmail.name + " created.");
               System.Console.WriteLine("Campaign ID: " + campaignId);
                
               // This attaches the list you made above to the campaign you just created. You can send an email to more than one list.
               setCampaignListsArgs objSCL = new setCampaignListsArgs();
               objSCL.session_id = sessionId;
               objSCL.campaign_id = campaignId;
               int[] listIds = new int[1];
               listIds[0] =  listId;

               objSCL.list_ids = listIds;

               try
               {
                   objVR.setCampaignLists(objSCL);
               }
               catch (Exception e)
               {
                   System.Console.WriteLine(e.Message);
               }

               /* 
                * Finally, let's launch the campaign! This will send the campaign to the VerticalResponse campaign checking team.
                * They make sure that all campaigns that we send out comply with US federal law and our terms of service.
                * If the campaign is declined, you'll receive an email at your log in email address explaining why.
               */

               launchEmailCampaignArgs objLEC = new launchEmailCampaignArgs();
               objLEC.session_id = sessionId;
               objLEC.campaign_id = campaignId;

               try
               {
                   objVR.launchEmailCampaign(objLEC);
               }
               catch (Exception e)
               {
                   System.Console.WriteLine(e.Message);
               }

                System.Console.WriteLine("Campaign launched!");

                // We do this to keep the terminal open when testing in Visual Studio. Feel free to delete it. 
                System.Console.WriteLine("Hit Enter to Exit the Terminal");
                System.Console.ReadLine(); 
              }
        }
}
